%----------------------------------------------------------------------------------
%
% Description :
% % This function m-file outputs channel parameters according to channel model.
%
% Programmed by R. Funada, H.Sawada, H. Harada, Y.Shoji, and C-H Choi
%----------------------------------------------------------------------------------

function [adist, nlos, los_beta_flag, Omega0, smallk, Lmean, Lam, lambda, Gam, ...
	gamma, std_ln_1, std_ln_2, sigma_fai, L_pl, tx_hpbw, rx_hpbw] = tg3c_tsv_params_r3(cm_num, fc)

% Arguments
% cm_num	channel model number
% fc		carrier center frequency in GHz

% Output parameters
% nlos		flag of NLOS environment
% Lmean		number of Average arrival clusters
% Lam		cluster arrival rate (clusters per nsec)
% lambda	ray arrival rate (rays per nsec)
% Gam		cluster decay factor (time constant, nsec)
% gamma		ray decay factor (time constant, nsec)
% std_ln_1	standard deviation of log-normal variable for cluster fading
% std_ln_2	standard deviation of log-normal variable for ray fading
% sigma_fai cluster angle-of-arrival spread in deg

% Parameters added by NICT
% adist				assuming distance between Tx and Rx in mapped usage model (meter)
% los_beta_flag		flag used for beta calculation (Renamed from LOS_desktop_flag) 
% this flag is also used for making LOS extraction for NLOS condition from a LOS condition.
% If this value is -1, the LOS component extraction mode is done
% Omega0			cluster power level
% smallk			small Rician factor
% L_pl				pathloss of the LOS component normalized with that of 1m
% tx_hpbw			Tx half-power angle in deg
% rx_hpbw			Rx half-power angle in deg

ramda	= 3e8/fc;

%******************* LOS Residential channel model (UM1) *******************
%IEEE 802.15-06-0393-00-003c
if cm_num == 11	% Experimental data Tx : 360deg, Rx : 15deg
	adist		= 5;
	nlos		= 0;
	los_beta_flag	= 0;
	Omega0		= -88.7;
	smallk		= 4.34;
	Lmean		= 9;
	Lam			= 1/5.24;	lambda = 1/0.820;
	Gam			= 4.46;		gamma = 6.25;
	std_ln_1	= 6.28;		std_ln_2	= 13.0;
	sigma_fai	= 49.8;
	tx_hpbw		= 360;
	rx_hpbw		= 15;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 12	% Experimental data Tx : 60deg, Rx : 15deg
	adist		= 5;
	nlos		= 0;
	los_beta_flag	= 0;
	Omega0		= -108;
	smallk		= 4.00;
	Lmean		= 11;
	Lam			= 1/5.15;	lambda = 1/1.11;
	Gam			= 8.98;		gamma = 9.17;
	std_ln_1	= 6.63;		std_ln_2	= 9.83;
	sigma_fai	= 119;
	tx_hpbw		= 60;	
	rx_hpbw		= 15;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 13	% Experimental data Tx : 30deg, Rx : 15deg
	adist		= 5;
	nlos		= 0;
	los_beta_flag	= 0;
	Omega0		= -111;
	smallk		= 2.73;
	Lmean		= 8;
	Lam			= 1/6.94;	lambda = 1/0.856;
	Gam			= 21.5;		gamma = 4.35;
	std_ln_1	= 3.71;		std_ln_2	= 7.31;
	sigma_fai	= 46.2;
	tx_hpbw		= 30;	
	rx_hpbw		= 15;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 14	% Experimental data Tx : 15deg, Rx : 15deg
	adist		= 5;
	nlos		= 0;
	los_beta_flag	= 0;
	Omega0		= -110.7;
	smallk		= 1.06;
	Lmean		= 4;
	Lam			= 1/22.2;	lambda = 1/1.08;
	Gam			= 12.6;		gamma =4.98;
	std_ln_1	= 7.34;		std_ln_2	= 6.11;
	sigma_fai	= 107;
	tx_hpbw		= 15;	
	rx_hpbw		= 15;	
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 15	%Experimental data Tx : 360deg, Rx : 15deg (SV model)
	adist		= 5;
	nlos		= 0;
	los_beta_flag	= -1;
	Omega0		= -20*log10(4*pi*adist/ramda); %N/A in channel model final reponrt
	smallk		= 0;
	Lmean		= 4;
	Lam			= 0.21;	lambda = 0.77;
	Gam			= 4.19;		gamma = 1.07;
	std_ln_1	= 1.54;		std_ln_2	= 1.26;
	sigma_fai	= 8.32;
	tx_hpbw		= 360;
	rx_hpbw		= 15;	
	L_pl		= -20*log10(4*pi*adist/ramda); %N/A in channel model final reponrt
%******************* NLOS Residential channel model (UM2) ******************
elseif cm_num == 21	% Experimental data Tx : 360deg, Rx : 15deg
	adist		= 5;
	nlos		= 1;
	los_beta_flag	= -1;
	Omega0		= -88.7;
	smallk		= 4.34;
	Lmean		= 9;
	Lam			= 1/5.24;	lambda = 1/0.820;
	Gam			= 4.46;		gamma = 6.25;
	std_ln_1	= 6.28;		std_ln_2	= 13.0;
	sigma_fai	= 49.8;
	tx_hpbw	= 360;
	rx_hpbw	= 15;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 22	% Experimental data Tx : 60deg, Rx : 15deg
	adist		= 5;
	nlos		= 1;
	los_beta_flag	= -1;
	Omega0		= -108;
	smallk		= 4.00;
	Lmean		= 11;
	Lam			= 1/5.15;	lambda = 1/1.11;
	Gam			= 8.98;		gamma = 9.17;
	std_ln_1	= 6.63;		std_ln_2	= 9.83;
	sigma_fai	= 119;
	tx_hpbw	= 60;	
	rx_hpbw	= 15;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 23	% Experimental data Tx : 30deg, Rx : 15deg
	adist		= 5;
	nlos		= 1;
	los_beta_flag	= -1;
	Omega0		= -111;
	smallk		= 2.73;
	Lmean		= 8;
	Lam			= 1/6.94;	lambda = 1/0.856;
	Gam			= 21.5;		gamma = 4.35;
	std_ln_1	= 3.71;		std_ln_2	= 7.31;
	sigma_fai	= 46.2;
	tx_hpbw	= 30;	
	rx_hpbw	= 15;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 24	% Experimental data Tx : 15deg, Rx : 15deg
	adist		= 5;
	nlos		= 1;
	los_beta_flag	= -1;
	Omega0		= -110.7;
	smallk		= 1.06;
	Lmean		= 4;
	Lam			= 1/22.2;	lambda = 1/1.08;
	Gam			= 12.6;		gamma =4.98;
	std_ln_1	= 7.34;		std_ln_2	= 6.11;
	sigma_fai	= 107;
	tx_hpbw	= 15;	
	rx_hpbw	= 15;	
	L_pl		= -20*log10(4*pi*adist/ramda);	
%********************** LOS Office channel model (UM3) *********************
%IEEE 802.15-06-0377-02-003c
elseif cm_num == 31	% Experimental data Tx : 30deg, Rx : 30deg
	adist		= 1;
	nlos		= 0;
	los_beta_flag	= 0;
	Omega0		= -3.27*adist-85.8;
	smallk		= 5.04;
	Lmean		= 6;
	Lam			= 1/24.6;	lambda = 1/1.03;
	Gam			= 49.8;		gamma = 45.2;
	std_ln_1	= 6.60;		std_ln_2	= 11.3;
	sigma_fai	= 102;
	tx_hpbw	= 30;	
	rx_hpbw	= 30;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 32	% Experimental data Tx : 60deg, Rx : 60deg
	adist		= 1;
	nlos		= 0;
	los_beta_flag	= 0;
	Omega0		= -0.303*adist-90.3;
	smallk		= 2.63;
	Lmean		= 5;
	Lam			= 1/37.6;	lambda = 1/3.41;
	Gam			= 38.8;		gamma = 64.9;
	std_ln_1	= 8.04;		std_ln_2	= 7.95;
	sigma_fai	= 66.4;
	tx_hpbw	= 60;
	rx_hpbw	= 60;
	L_pl		= -20*log10(4*pi*adist/ramda);
	
%********************* NLOS Office channel model (UM4) *********************
%IEEE 802.15-06-0478-01-003c
elseif cm_num == 41	% Experimental data Tx : 360deg, Rx : 15deg
	adist		= 5;
	nlos		= 1;
	los_beta_flag	= 0;
	Omega0		= -109;
	smallk		= 4.37;
	Lmean		= 5;
	Lam			= 1/30.8;	lambda = 1/0.29;
	Gam			= 109.2;	gamma = 67.9;
	std_ln_1	= 3.24;		std_ln_2	= 5.54;
	sigma_fai	= 60.2;
	tx_hpbw	= 360;	
	rx_hpbw	= 15;
	a_nlos		= 5.56;
	L_pl		= -a_nlos-10*3.35*log10(4*pi*adist/ramda);
elseif cm_num == 42	% Experimental data Tx : 30deg, Rx : 15deg
	adist		= 5;
	nlos		= 1;
	los_beta_flag	= 0;
	Omega0		= -107.2;
	smallk		= 4.43;
	Lmean		= 5;
	Lam			= 1/35.9;	lambda = 1/1.32;
	Gam			= 134.0;		gamma = 59.0;
	std_ln_1	= 4.37;		std_ln_2	= 6.66;
	sigma_fai	= 22.2;
	tx_hpbw	= 30;
	rx_hpbw	= 15;
	a_nlos		= 5.56;
	L_pl		= -a_nlos-10*3.35*log10(4*pi*adist/ramda);
	%************************ LOS Desktop channel model (CM9) ************************
%IEEE 802. 15-06-0297-03-003c
elseif cm_num == 71	% Experimental data Tx : 30deg, Rx : 30deg
	adist		= 3;
	nlos		= 0;
	los_beta_flag	= 1;
	Omega0		= 4.44*adist-105.4;
	smallk		= 2.53;
	Lmean		= 3;
	Lam			= 1/27.0;	lambda	= 1/1.56;
	Gam			= 21.1;		gamma	= 8.85;
	std_ln_1	= 3.01;		std_ln_2= 7.69;
	sigma_fai	= 34.6;
	tx_hpbw	= 30;
	rx_hpbw	= 30;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 72	% Experimental data Tx : 60deg, Rx : 60deg
	adist		= 1;
	nlos		= 0;
	los_beta_flag	= 1;	
	Omega0		= 3.46*adist-98.4;
	smallk		= 3.97;
	Lmean		= 3;
	Lam			= 1/21.1;	lambda	= 1/2.68;
	Gam			= 22.3;		gamma	= 17.2;
	std_ln_1	= 7.27;		std_ln_2= 4.42;
	sigma_fai	= 38.1;
	tx_hpbw	= 60;
	rx_hpbw	= 60;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 81	% Experimental data Tx : 30deg, Rx : 30deg
	adist		= 3;
	nlos		= 1;
	los_beta_flag	= -1;
	Omega0		= 4.44*adist-105.4;
	smallk		= 2.53;
	Lmean		= 3;
	Lam			= 1/27.0;	lambda	= 1/1.56;
	Gam			= 21.1;		gamma	= 8.85;
	std_ln_1	= 3.01;		std_ln_2= 7.69;
	sigma_fai	= 34.6;
	tx_hpbw	= 30;
	rx_hpbw	= 30;
	L_pl		= -20*log10(4*pi*adist/ramda);
elseif cm_num == 82	% Experimental data Tx : 60deg, Rx : 60deg
	adist		= 1;
	nlos		= 1;
	los_beta_flag	= -1;
	Omega0		= 3.46*adist-98.4;
	smallk		= 3.97;
	Lmean		= 3;
	Lam			= 1/21.1;	lambda	= 1/2.68;
	Gam			= 22.3;		gamma	= 17.2;
	std_ln_1	= 7.27;		std_ln_2= 4.42;
	sigma_fai	= 38.1;
	tx_hpbw	= 60;
	rx_hpbw	= 60;
	L_pl		= -20*log10(4*pi*adist/ramda);
else
	error('cm_num error');
end

